use strict;
use warnings;
use utf8;
use Test::More;
use Test::Exception;
use Email::MIME::MobileJP::Creator::AltEnc;
use Encode ();

subtest 'single part(docomo)' => sub {
    my $orig = \&MIME::Words::encode_mimeword;
    my $creator = Email::MIME::MobileJP::Creator::AltEnc->new('おなまえ <docomo.taro.@docomo.ne.jp>');
    is $creator->header('To'), 'おなまえ <docomo.taro.@docomo.ne.jp>';
    $creator->subject('Hello こんにちわ!');
    $creator->body('ほげほげ');

    is $creator->subject(), 'Hello こんにちわ!';
    is $creator->body(), 'ほげほげ';
    is $creator->mail->content_type(), 'text/plain; charset="Shift_JIS"';

    my $mail = $creator->finalize();
    my $str = $mail->as_string;
    ok !Encode::is_utf8($mail->header_obj->as_string);
    ok !Encode::is_utf8($str);
    like $str, qr{\QTo: =?Shift_JIS?B?gqiCyILcgqY=?= <docomo.taro.\E\@\Qdocomo.ne.jp>\E};
    like $str, qr{\QSubject: =?Shift_JIS?B?SGVsbG8ggrGC8YLJgr+C7SE=?=};
    note $str;
};

lives_ok { 
    my $creator = Email::MIME::MobileJP::Creator::AltEnc->new('docomo.taro.@docomo.ne.jp');
    $creator->subject("日本語");
};

lives_ok { 
    my $creator = Email::MIME::MobileJP::Creator::AltEnc->new('user@non-mobile.jp');
    $creator->subject("日本語");
};

done_testing;
